@@ -7,4 +7,4 @@ from .optics import *
 from .scatterers import *
 from .sequences import *
 
-from . import image, losses, generators, models, utils, layers
\ No newline at end of file
+from . import image, losses, generators, models, utils, layers, backend
\ No newline at end of file
